package com.ruoyi.project.patrol.patrol.mapper;

import com.ruoyi.project.patrol.patrol.domain.TPatrolIssues;

import java.util.List;

/**
 * 检查问题记录Mapper接口
 *
 * @author ruoyi
 * @date 2023-09-25
 */
public interface TPatrolIssuesMapper
{
    /**
     * 查询检查问题记录
     *
     * @param id 检查问题记录主键
     * @return 检查问题记录
     */
    public TPatrolIssues selectTPatrolIssuesById(Long id);

    /**
     * 查询检查问题记录列表
     *
     * @param tPatrolIssues 检查问题记录
     * @return 检查问题记录集合
     */
    public List<TPatrolIssues> selectTPatrolIssuesList(TPatrolIssues tPatrolIssues);

    /**
     * 新增检查问题记录
     *
     * @param tPatrolIssues 检查问题记录
     * @return 结果
     */
    public int insertTPatrolIssues(TPatrolIssues tPatrolIssues);

    /**
     * 修改检查问题记录
     *
     * @param tPatrolIssues 检查问题记录
     * @return 结果
     */
    public int updateTPatrolIssues(TPatrolIssues tPatrolIssues);

    /**
     * 删除检查问题记录
     *
     * @param id 检查问题记录主键
     * @return 结果
     */
    public int deleteTPatrolIssuesById(Long id);

    /**
     * 批量删除检查问题记录
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTPatrolIssuesByIds(Long[] ids);
}
